#
# spec file for package perl-XML-Parser
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name XML-Parser
Name:           perl-XML-Parser
Version:        2.470.0
Release:        3.2
%define cpan_version 2.47
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl module for parsing XML documents
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/T/TO/TODDR/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
Patch0:         XML-Parser-2.40.diff
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(LWP::UserAgent)
Requires:       perl(LWP::UserAgent)
Provides:       perl(XML::Parser) = %{version}
Provides:       perl(XML::Parser::Expat)
Provides:       perl(XML::Parser::Style::Debug)
Provides:       perl(XML::Parser::Style::Objects)
Provides:       perl(XML::Parser::Style::Stream)
Provides:       perl(XML::Parser::Style::Subs)
Provides:       perl(XML::Parser::Style::Tree)
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  libexpat-devel
# MANUAL END

%description
This module provides ways to parse XML documents. It is built on top of
XML::Parser::Expat, which is a lower level interface to James Clark's expat
library. Each call to one of the parsing methods creates a new instance of
XML::Parser::Expat which is then used to parse the document. Expat options
may be provided when the XML::Parser object is created. These options are
then passed on to the Expat object on each parse call. They can also be
given as extra arguments to the parse methods, in which case they override
options given at XML::Parser creation time.

The behavior of the parser is controlled either by 'STYLES' and/or
'HANDLERS' options, or by setHandlers method. These all provide mechanisms
for XML::Parser to set the handlers needed by XML::Parser::Expat. If
neither 'Style' nor 'Handlers' are specified, then parsing just checks the
document for being well-formed.

When underlying handlers get called, they receive as their first parameter
the _Expat_ object, not the Parser object.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p0

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
chmod 644 samples/{canonical,xml*}
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README README.md samples
%license LICENSE

%changelog
* Tue Oct 15 2024 Joel Baltazor <obs@mtlfab.com>
- Get package to show provides perl(XML::Parser::Expat) and other submodules
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Fri Dec 29 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.47
  see /usr/share/doc/packages/perl-XML-Parser/Changes
  2.47 2023-12-28 (by Todd Rinaldo)
  - #84 use $fh instead of $foo
  - #85 Fix typo in documentation
  - #89 Devel::CheckLib to from 0.99 -> 1.14
  - Devel::CheckLibn 1.16
  - #91 POD fix for verbatim text
  - #97 Add a LICENSE file
  - #94 Don't ship Expat/Makefile
  - Various github workflow improvements. Windows is still not working.
* Thu Sep 26 2019 Tina Mueller <tina.mueller@suse.com>
- Fix syntax for patch in cpanspec.yml
* Thu Sep 26 2019 Tina Mueller <tina.mueller@suse.com>
- updated to 2.46
  see /usr/share/doc/packages/perl-XML-Parser/Changes
* Wed Aug 21 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Add cpanspec.yml file
* Wed Aug 21 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Remove not needed files in doc section [bsc#1146634]
- Fix permissions in samples directory
* Wed Aug 21 2019 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Updated spec file with spec-celaner
- Use https and metacpan release
* Sun Feb  8 2015 coolo@suse.com
- avoid a cycle with LWP
* Sat Feb  7 2015 coolo@suse.com
- updated to 2.44
  - RT 99098 - Revert "Add more useful error message on parse to Expat". It breaks
    XML::Twig. Calling code will need to do this if it's needed.
  - RT 100959 - Add use FileHandle to t/astress.t - Make perl 5.10.0 happy.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 2.43
  + POD patch to man from Debian via Nicholas Bamber
  + POD patch from Debian via gregor herrmann.
  + Add more useful error message on parse to Expat
  + Fix LWP dependency to be LWP::Useragent
  + Bump to 2.43 for overdue release to CPAN.
- Remove obsolete Authors section
- Remove redundant %%clean section
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Tue Aug 30 2011 andrea.turrini@gmail.com
- standardized "Authors:" format in description of perl-XML-Parser.spec
* Mon Jun  6 2011 vcizek@novell.com
- update to 2.41
  - better installation instructions
  - Small spelling patches from Debian package - Thanks Nicholas Bamber
  - RT 68399 - Upgrade Devel::CheckLib to 0.93 to make it
    perl 5.14 compliant - qw()
  - RT 67207 - Stop doing tied on globs - Thanks sprout
  - RT 31319 - Fix doc links in POD for XML/Parser.pm
* Wed Mar 16 2011 cfarrell@novell.com
- license update: GPL+ or Artistic
  Same license as Perl itself is GPL+ or Artistic in our rpm license syntax
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Sep 21 2010 anicka@suse.cz
- update to 2.40
  * Add windows-1251.enc, ibm866.enc, koi8-r.enc (Russian)
  * Add windows-1255.enc (Hebrew)
  * Update iso-8859-7.enc (RT#40712)
  * Use Devel::CheckLib
  * Better description of expat packages
  * Better Perl style in both code and docs
* Mon May 10 2010 anicka@suse.cz
- fixed URL in spec (bnc#604084)
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Tue Jul 14 2009 chris@computersalat.de
- some spec mods
  o fixed summary, description
- added perl-macros
  o autogen filelist with perl_gen_filelist
- some rpmlint fixes
  o file permissions
* Wed Nov 21 2007 anicka@suse.cz
- update to 2.36
  * Fix for Carp::Heavy bugs
  * Added license in Makefile.PL
  * Makefile.PL also searches for expat in C:/lib/Expat-2.0.0
  * No longer uses variable named 'namespace' in Expat.xs
* Thu Jul 19 2007 coolo@suse.de
- remove explicit lib requires
* Mon Jul 16 2007 anicka@suse.cz
- change dependency on expat to libexpat
* Fri Apr 27 2007 aj@suse.de
- Add libexpat-devel to BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.34
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Tue Jul 15 2003 mjancar@suse.cz
- adapt to perl-5.8.1
- use %%perl_process_packlist
* Mon Jun 16 2003 mjancar@suse.cz
- use $RPM_OPT_FLAGS
- fix filelist
* Mon May 19 2003 ro@suse.de
- remove perllocal.pod
* Tue Jul 23 2002 prehak@suse.cz
- update to version 2.31
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Tue Nov 20 2001 rvasice@suse.cz
- fixed requires
* Tue Sep  4 2001 rvasice@suse.cz
- fixed Group tag to Development/Libraries/Perl
* Thu Aug 16 2001 rvasice@suse.cz
- update to version 2.30
* Fri Nov 10 2000 cihlar@suse.cz
- renamed p_xmlpar -> perl-XML-Parser
- bzipped sources
- fixed copyright tag
* Mon Aug 21 2000 ro@suse.de
- adapted for perl-5.6
* Thu Apr 20 2000 cihlar@suse.cz
- added BuildRoot
* Thu Jan 20 2000 ro@suse.de
- use macro for mandir
* Mon Jan 10 2000 ke@suse.de
- Update: version 2.27.
- Use version macro.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug 23 1999 ro@suse.de
- added missing Parser.pm to filelist
* Wed Aug  4 1999 ke@suse.de
- New package: version 1.23.
